import React, { lazy, Suspense, useEffect, useState } from 'react';
import { BrowserRouter as Router, Routes, Route, useLocation } from 'react-router-dom';
import { HelmetProvider, Helmet } from 'react-helmet-async';
import { ErrorBoundary } from 'react-error-boundary';
import { Header } from './components/layout/Header';
import { Footer } from './components/layout/Footer';
import { Home } from './pages/Home';

// Lazy load non-critical pages for better performance
const Apps = lazy(() => import('./pages/Apps').then(module => ({ default: module.Apps })));
const Blog = lazy(() => import('./pages/Blog').then(module => ({ default: module.Blog })));
const BlogPost = lazy(() => import('./pages/BlogPost').then(module => ({ default: module.BlogPost })));
const YouTube = lazy(() => import('./pages/YouTube').then(module => ({ default: module.YouTube })));
const Contact = lazy(() => import('./pages/Contact').then(module => ({ default: module.Contact })));
const About = lazy(() => import('./pages/About').then(module => ({ default: module.About })));
const PrivacyPolicy = lazy(() => import('./pages/PrivacyPolicy').then(module => ({ default: module.PrivacyPolicy })));
const TermsOfService = lazy(() => import('./pages/TermsOfService').then(module => ({ default: module.TermsOfService })));
const RefundPolicy = lazy(() => import('./pages/RefundPolicy').then(module => ({ default: module.RefundPolicy })));

const helmetContext = {};

// Scroll to top on route change
function ScrollToTop() {
  const { pathname } = useLocation();
  
  useEffect(() => {
    window.scrollTo(0, 0);
    // Announce page change for screen readers
    const title = document.title || 'Niogram';
    const announcement = document.getElementById('page-announcement');
    if (announcement) {
      announcement.textContent = `Navigated to ${title}`;
    }
  }, [pathname]);
  
  return null;
}

// Fallback for lazy-loaded components with better animations
const PageLoader = () => (
  <div className="flex items-center justify-center min-h-screen">
    <div className="animate-pulse bg-gradient-to-r from-purple-500 to-indigo-500 p-4 rounded-full">
      <div className="w-8 h-8 rounded-full border-4 border-white border-t-transparent animate-spin" aria-label="Loading content..."></div>
    </div>
  </div>
);

// Error fallback component
const ErrorFallback = ({ error, resetErrorBoundary }: { error: Error; resetErrorBoundary: () => void }) => (
  <div className="min-h-screen flex items-center justify-center p-4 bg-gradient-to-b from-black to-purple-950/30" role="alert" aria-live="assertive">
    <div className="bg-white/10 backdrop-blur-lg p-8 rounded-xl max-w-2xl text-center">
      <h2 className="text-3xl font-bold text-white mb-4">Something went wrong</h2>
      <p className="text-red-300 mb-6">{error.message}</p>
      <button
        onClick={resetErrorBoundary}
        className="px-6 py-3 bg-gradient-to-r from-purple-600 to-indigo-600 text-white font-medium rounded-lg hover:shadow-lg hover:shadow-purple-500/30 transition-all"
      >
        Try again
      </button>
    </div>
  </div>
);

// Debug and diagnostic information component
const Diagnostics = () => {
  const [visible, setVisible] = useState(false);
  
  if (!visible) {
    return (
      <button
        onClick={() => setVisible(true)}
        className="fixed bottom-4 right-4 p-2 bg-purple-600 text-white rounded-full z-50"
        aria-label="Show diagnostics"
      >
        🛠️
      </button>
    );
  }
  
  return (
    <div className="fixed inset-0 bg-black/80 backdrop-blur-sm z-50 p-4 overflow-auto text-white font-mono">
      <div className="bg-purple-900/50 p-4 rounded max-w-4xl mx-auto">
        <div className="flex justify-between items-center mb-4">
          <h2 className="text-xl font-bold">Diagnostics Panel</h2>
          <button onClick={() => setVisible(false)} className="bg-purple-700 px-3 py-1 rounded">
            Close
          </button>
        </div>
        
        <div className="grid gap-4">
          <section className="border border-purple-700 p-3 rounded">
            <h3 className="font-bold mb-2">Browser Info</h3>
            <p className="text-sm">User Agent: {navigator.userAgent}</p>
            <p className="text-sm">Window Size: {window.innerWidth}x{window.innerHeight}</p>
            <p className="text-sm">Viewport: {window.visualViewport?.width}x{window.visualViewport?.height}</p>
          </section>
          
          <section className="border border-purple-700 p-3 rounded">
            <h3 className="font-bold mb-2">React Info</h3>
            <p className="text-sm">React Version: {React.version}</p>
            <p className="text-sm">Strict Mode: Enabled</p>
            <p className="text-sm">Error Boundary: Active</p>
          </section>
          
          <section className="border border-purple-700 p-3 rounded">
            <h3 className="font-bold mb-2">Actions</h3>
            <div className="flex gap-2">
              <button 
                onClick={() => console.log('App state diagnostic test')} 
                className="bg-purple-700 px-3 py-1 rounded text-sm"
              >
                Log Test
              </button>
              <button 
                onClick={() => window.location.reload()} 
                className="bg-purple-700 px-3 py-1 rounded text-sm"
              >
                Reload
              </button>
              <button 
                onClick={() => localStorage.clear()} 
                className="bg-purple-700 px-3 py-1 rounded text-sm"
              >
                Clear Storage
              </button>
            </div>
          </section>
        </div>
      </div>
    </div>
  );
};

export default function App() {
  // Diagnostic state
  const [hasRendered, setHasRendered] = useState(false);
  
  // Add global event listeners
  useEffect(() => {
    // Mark as rendered
    setHasRendered(true);
    
    // Add keyboard navigation support
    const handleKeyDown = (e: KeyboardEvent) => {
      // Add keyboard shortcuts or navigation here if needed
      if (e.key === '/' && (e.ctrlKey || e.metaKey)) {
        e.preventDefault();
        // Implement search functionality
        console.log('Search shortcut pressed');
      }
    };
    
    window.addEventListener('keydown', handleKeyDown);
    return () => {
      window.removeEventListener('keydown', handleKeyDown);
    };
  }, []);
  
  return (
    <HelmetProvider context={helmetContext}>
      <Helmet>
        <html lang="en" />
        <meta name="theme-color" content="#7c3aed" />
      </Helmet>
      <ErrorBoundary FallbackComponent={ErrorFallback}>
        {/* Only render diagnostics in development mode - now removed */}
      <Router>
          <ScrollToTop />
          <div className="min-h-screen flex flex-col bg-gradient-to-b from-black to-purple-950">
            {/* Accessibility features */}
            <div id="page-announcement" className="sr-only" aria-live="polite"></div>
            <a href="#main-content" className="sr-only focus:not-sr-only focus:fixed focus:z-50 focus:top-4 focus:left-4 focus:px-4 focus:py-2 focus:bg-purple-600 focus:text-white focus:rounded-md">
              Skip to main content
            </a>
          <Header />
            <main id="main-content" className="flex-grow mt-16" tabIndex={-1}>
              {!hasRendered ? (
                <div className="flex items-center justify-center min-h-screen">
                  <div className="text-white text-center">
                    <div className="animate-spin w-12 h-12 border-4 border-purple-500 border-t-transparent rounded-full mx-auto mb-4"></div>
                    <p className="text-purple-300">Loading Niogram...</p>
                  </div>
                </div>
              ) : (
                <Suspense fallback={<PageLoader />}>
          <Routes>
            <Route path="/" element={<Home />} />
            <Route path="/apps" element={<Apps />} />
            <Route path="/blog" element={<Blog />} />
            <Route path="/blog/:slug" element={<BlogPost />} />
            <Route path="/youtube" element={<YouTube />} />
            <Route path="/about" element={<About />} />
            <Route path="/contact" element={<Contact />} />
            <Route path="/privacy" element={<PrivacyPolicy />} />
            <Route path="/terms" element={<TermsOfService />} />
            <Route path="/refunds" element={<RefundPolicy />} />
            <Route path="*" element={<NotFound />} />
          </Routes>
                </Suspense>
              )}
            </main>
          <Footer />
        </div>
      </Router>
      </ErrorBoundary>
    </HelmetProvider>
  );
}

// 404 Page
const NotFound = () => {
  // Animation sequence states
  const [isLoaded, setIsLoaded] = React.useState(false);
  
  React.useEffect(() => {
    setTimeout(() => setIsLoaded(true), 100);
    
    // Update document title for accessibility
    document.title = "Page Not Found - Niogram";
  }, []);
  
  return (
    <div className="min-h-screen flex flex-col items-center justify-center py-20 px-4" role="main" aria-labelledby="404-title">
      <Helmet>
        <title>Page Not Found - Niogram</title>
        <meta name="description" content="The page you're looking for doesn't exist or has been moved." />
      </Helmet>
      
      <div className="w-full max-w-3xl mx-auto text-center relative">
        {/* Background elements */}
        <div className="absolute inset-0 -z-10">
          <div className="absolute top-1/2 left-1/2 -translate-x-1/2 -translate-y-1/2 w-96 h-96 bg-purple-500/20 rounded-full blur-[100px]"></div>
          <div className="absolute top-1/3 right-1/4 w-64 h-64 bg-indigo-500/20 rounded-full blur-[80px]"></div>
        </div>
        
        {/* 404 number */}
        <div className={`relative transition-all duration-1000 ${isLoaded ? 'opacity-100 translate-y-0' : 'opacity-0 translate-y-10'}`}>
          <div className="text-[180px] font-bold leading-none tracking-tighter">
            <div className="relative inline-block">
              <span className="absolute inset-0 text-purple-500/20 blur-xl animate-pulse">404</span>
              <span className="relative bg-gradient-to-b from-white via-purple-200 to-purple-500 bg-clip-text text-transparent">404</span>
            </div>
          </div>
        </div>
        
        {/* Error message */}
        <div className={`transition-all duration-1000 delay-300 ${isLoaded ? 'opacity-100 translate-y-0' : 'opacity-0 translate-y-10'}`}>
          <h1 id="404-title" className="text-3xl md:text-4xl font-bold text-white mb-4">Page Not Found</h1>
          <p className="text-lg text-purple-200/80 max-w-lg mx-auto mb-8">
            The page you're looking for doesn't exist or has been moved. Check the URL or navigate back to the homepage.
          </p>
          
          {/* Glitch element */}
          <div className="h-0.5 w-48 mx-auto mb-10 relative overflow-hidden" aria-hidden="true">
            <div className="absolute inset-0 bg-gradient-to-r from-transparent via-purple-500 to-transparent"></div>
            <div className="absolute inset-0 bg-gradient-to-r from-transparent via-indigo-400 to-transparent animate-pulse"></div>
          </div>
          
          {/* Button group */}
          <div className="flex flex-col sm:flex-row gap-4 justify-center mb-8">
            <a 
              href="/"
              className="px-6 py-3 bg-gradient-to-r from-purple-600 to-indigo-600 rounded-lg text-white font-medium hover:shadow-lg hover:shadow-purple-500/20 transition-all hover:scale-105"
              aria-label="Return to homepage"
            >
              Return Home
            </a>
            <a 
              href="/contact"
              className="px-6 py-3 bg-black/30 border border-purple-500/20 backdrop-blur-sm rounded-lg text-purple-100 font-medium hover:bg-purple-950/40 hover:border-purple-400/30 transition-all"
              aria-label="Contact our support team"
            >
              Contact Support
            </a>
          </div>
          
          {/* Suggestion links */}
          <div className={`transition-all duration-1000 delay-500 ${isLoaded ? 'opacity-100 translate-y-0' : 'opacity-0 translate-y-10'}`}>
            <p className="text-gray-400 mb-4">You might be interested in:</p>
            <div className="flex flex-wrap justify-center gap-3">
              {[
                { label: 'Apps', path: '/apps' },
                { label: 'Blog', path: '/blog' },
                { label: 'YouTube', path: '/youtube' },
                { label: 'About', path: '/about' }
              ].map((link, index) => (
                <a 
                  key={index}
                  href={link.path}
                  className="px-4 py-2 bg-white/5 rounded-lg text-purple-100 hover:bg-white/10 transition-colors"
                >
                  {link.label}
                </a>
              ))}
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};